package cn.com.qmth.examcloud.config.center.core;

import java.util.Map;
import java.util.Map.Entry;
import java.util.Properties;
import java.util.Set;

import org.apache.commons.lang3.StringUtils;

import com.google.common.collect.Maps;
import com.google.common.collect.Sets;

import cn.com.qmth.examcloud.commons.util.PropertiesUtil;
import cn.com.qmth.examcloud.web.bootstrap.BootstrapSecurityUtil;

/**
 * 配置加载器
 *
 * @author WANGWEI
 * @date 2019年5月15日
 * @Copyright (c) 2018-? http://qmth.com.cn All Rights Reserved.
 */
public class PropertiesLoader {

	/**
	 * 保存启动配置属性
	 *
	 * @author WANGWEI
	 * @param appCode
	 * @param active
	 */
	public static Map<String, String> getProperties(String appCode, String active) {

		Properties props = new Properties();
		String resource1 = active + "/application.properties";
		String resource2 = active + "/application-" + appCode + ".properties";

		try {
			PropertiesUtil.loadFromResource(resource1, props);
		} catch (Exception e) {
			String errorMessage = "fail to load properties file [" + resource1 + "]";
			throw new RuntimeException(errorMessage);
		}

		BootstrapSecurityUtil.decrypt(props, BootstrapSecurityManager.getInstance().getSecretKey());

		try {
			PropertiesUtil.loadFromResource(resource2, props);
		} catch (Exception e) {
			String errorMessage = "fail to load properties file [" + resource2 + "]";
			throw new RuntimeException(errorMessage);
		}

		BootstrapSecurityUtil.decrypt(props, BootstrapSecurityManager.getInstance().getSecretKey());

		Map<String, String> map = Maps.newHashMap();
		for (Entry<Object, Object> entry : props.entrySet()) {
			map.put(String.valueOf(entry.getKey()), String.valueOf(entry.getValue()));
		}

		filter(map);
		return map;
	}

	private static void filter(Map<String, String> properties) {
		Set<String> removedKeySet = Sets.newHashSet();

		String datasourceType = properties.get("spring.datasource.type");
		if (StringUtils.isNotBlank(datasourceType)) {
			if (datasourceType.equalsIgnoreCase("null")) {
				for (String key : properties.keySet()) {
					if (key.startsWith("spring.datasource")) {
						removedKeySet.add(key);
					}
				}
			}
		}

		for (String key : removedKeySet) {
			properties.remove(key);
		}

	}

}
